@@ -22,4 +22,6 @@
 mod catalog;
 pub use catalog::*;
 
+mod error;
+mod schema;
 mod utils;
