@@ -174,12 +174,18 @@ impl Catalog for MemoryCatalog {
                 let location_prefix = match namespace_properties.get(LOCATION) {
                     Some(namespace_location) => Ok(namespace_location.clone()),
                     None => match self.warehouse_location.clone() {
-                        Some(warehouse_location) => Ok(format!("{}/{}", warehouse_location, namespace_ident.join("/"))),
-                        None => Err(Error::new(ErrorKind::Unexpected,
+                        Some(warehouse_location) => Ok(format!(
+                            "{}/{}",
+                            warehouse_location,
+                            namespace_ident.join("/")
+                        )),
+                        None => Err(Error::new(
+                            ErrorKind::Unexpected,
                             format!(
                                 "Cannot create table {:?}. No default path is set, please specify a location when creating a table.",
                                 &table_ident
-                            )))
+                            ),
+                        )),
                     },
                 }?;
 
@@ -240,7 +246,8 @@ impl Catalog for MemoryCatalog {
     async fn drop_table(&self, table_ident: &TableIdent) -> Result<()> {
         let mut root_namespace_state = self.root_namespace_state.lock().await;
 
-        root_namespace_state.remove_existing_table(table_ident)
+        let metadata_location = root_namespace_state.remove_existing_table(table_ident)?;
+        self.file_io.delete(&metadata_location).await
     }
 
     /// Check if a table exists in the catalog.
@@ -321,12 +328,9 @@ mod tests {
 
     fn simple_table_schema() -> Schema {
         Schema::builder()
-            .with_fields(vec![NestedField::required(
-                1,
-                "foo",
-                Type::Primitive(PrimitiveType::Int),
-            )
-            .into()])
+            .with_fields(vec![
+                NestedField::required(1, "foo", Type::Primitive(PrimitiveType::Int)).into(),
+            ])
             .build()
             .unwrap()
     }
@@ -528,10 +532,12 @@ mod tests {
         let namespace_ident = NamespaceIdent::new("a".into());
         create_namespace(&catalog, &namespace_ident).await;
 
-        assert!(!catalog
-            .namespace_exists(&NamespaceIdent::new("b".into()))
-            .await
-            .unwrap());
+        assert!(
+            !catalog
+                .namespace_exists(&NamespaceIdent::new("b".into()))
+                .await
+                .unwrap()
+        );
     }
 
     #[tokio::test]
@@ -597,7 +603,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => Cannot create namespace {:?}. Namespace already exists.",
+                "NamespaceAlreadyExists => Cannot create namespace {:?}. Namespace already exists.",
                 &namespace_ident
             )
         );
@@ -666,7 +672,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => No such namespace: {:?}",
+                "NamespaceNotFound => No such namespace: {:?}",
                 NamespaceIdent::new("a".into())
             )
         );
@@ -675,8 +681,8 @@ mod tests {
     }
 
     #[tokio::test]
-    async fn test_create_deeply_nested_namespace_throws_error_if_intermediate_namespace_doesnt_exist(
-    ) {
+    async fn test_create_deeply_nested_namespace_throws_error_if_intermediate_namespace_doesnt_exist()
+     {
         let catalog = new_memory_catalog();
 
         let namespace_ident_a = NamespaceIdent::new("a".into());
@@ -691,7 +697,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => No such namespace: {:?}",
+                "NamespaceNotFound => No such namespace: {:?}",
                 NamespaceIdent::from_strs(vec!["a", "b"]).unwrap()
             )
         );
@@ -772,7 +778,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => No such namespace: {:?}",
+                "NamespaceNotFound => No such namespace: {:?}",
                 non_existent_namespace_ident
             )
         )
@@ -859,7 +865,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => No such namespace: {:?}",
+                "NamespaceNotFound => No such namespace: {:?}",
                 non_existent_namespace_ident
             )
         )
@@ -885,10 +891,12 @@ mod tests {
 
         catalog.drop_namespace(&namespace_ident_a_b).await.unwrap();
 
-        assert!(!catalog
-            .namespace_exists(&namespace_ident_a_b)
-            .await
-            .unwrap());
+        assert!(
+            !catalog
+                .namespace_exists(&namespace_ident_a_b)
+                .await
+                .unwrap()
+        );
 
         assert!(catalog.namespace_exists(&namespace_ident_a).await.unwrap());
     }
@@ -911,15 +919,19 @@ mod tests {
             .await
             .unwrap();
 
-        assert!(!catalog
-            .namespace_exists(&namespace_ident_a_b_c)
-            .await
-            .unwrap());
+        assert!(
+            !catalog
+                .namespace_exists(&namespace_ident_a_b_c)
+                .await
+                .unwrap()
+        );
 
-        assert!(catalog
-            .namespace_exists(&namespace_ident_a_b)
-            .await
-            .unwrap());
+        assert!(
+            catalog
+                .namespace_exists(&namespace_ident_a_b)
+                .await
+                .unwrap()
+        );
 
         assert!(catalog.namespace_exists(&namespace_ident_a).await.unwrap());
     }
@@ -936,7 +948,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => No such namespace: {:?}",
+                "NamespaceNotFound => No such namespace: {:?}",
                 non_existent_namespace_ident
             )
         )
@@ -956,7 +968,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => No such namespace: {:?}",
+                "NamespaceNotFound => No such namespace: {:?}",
                 non_existent_namespace_ident
             )
         )
@@ -973,10 +985,12 @@ mod tests {
 
         assert!(!catalog.namespace_exists(&namespace_ident_a).await.unwrap());
 
-        assert!(!catalog
-            .namespace_exists(&namespace_ident_a_b)
-            .await
-            .unwrap());
+        assert!(
+            !catalog
+                .namespace_exists(&namespace_ident_a_b)
+                .await
+                .unwrap()
+        );
     }
 
     #[tokio::test]
@@ -1009,11 +1023,13 @@ mod tests {
 
         assert_table_eq(&table, &expected_table_ident, &simple_table_schema());
 
-        assert!(table
-            .metadata_location()
-            .unwrap()
-            .to_string()
-            .starts_with(&location))
+        assert!(
+            table
+                .metadata_location()
+                .unwrap()
+                .to_string()
+                .starts_with(&location)
+        )
     }
 
     #[tokio::test]
@@ -1058,8 +1074,8 @@ mod tests {
     }
 
     #[tokio::test]
-    async fn test_create_table_in_nested_namespace_falls_back_to_nested_namespace_location_if_table_location_is_missing(
-    ) {
+    async fn test_create_table_in_nested_namespace_falls_back_to_nested_namespace_location_if_table_location_is_missing()
+     {
         let file_io = FileIOBuilder::new_fs_io().build().unwrap();
         let warehouse_location = temp_path();
         let catalog = MemoryCatalog::new(file_io, Some(warehouse_location.clone()));
@@ -1111,8 +1127,8 @@ mod tests {
     }
 
     #[tokio::test]
-    async fn test_create_table_falls_back_to_warehouse_location_if_both_table_location_and_namespace_location_are_missing(
-    ) {
+    async fn test_create_table_falls_back_to_warehouse_location_if_both_table_location_and_namespace_location_are_missing()
+     {
         let file_io = FileIOBuilder::new_fs_io().build().unwrap();
         let warehouse_location = temp_path();
         let catalog = MemoryCatalog::new(file_io, Some(warehouse_location.clone()));
@@ -1152,8 +1168,8 @@ mod tests {
     }
 
     #[tokio::test]
-    async fn test_create_table_in_nested_namespace_falls_back_to_warehouse_location_if_both_table_location_and_namespace_location_are_missing(
-    ) {
+    async fn test_create_table_in_nested_namespace_falls_back_to_warehouse_location_if_both_table_location_and_namespace_location_are_missing()
+     {
         let file_io = FileIOBuilder::new_fs_io().build().unwrap();
         let warehouse_location = temp_path();
         let catalog = MemoryCatalog::new(file_io, Some(warehouse_location.clone()));
@@ -1200,8 +1216,8 @@ mod tests {
     }
 
     #[tokio::test]
-    async fn test_create_table_throws_error_if_table_location_and_namespace_location_and_warehouse_location_are_missing(
-    ) {
+    async fn test_create_table_throws_error_if_table_location_and_namespace_location_and_warehouse_location_are_missing()
+     {
         let file_io = FileIOBuilder::new_fs_io().build().unwrap();
         let catalog = MemoryCatalog::new(file_io, None);
 
@@ -1256,7 +1272,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => Cannot create table {:?}. Table already exists.",
+                "TableAlreadyExists => Cannot create table {:?}. Table already exists.",
                 &table_ident
             )
         );
@@ -1358,7 +1374,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => No such namespace: {:?}",
+                "NamespaceNotFound => No such namespace: {:?}",
                 non_existent_namespace_ident
             ),
         );
@@ -1408,7 +1424,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => No such namespace: {:?}",
+                "NamespaceNotFound => No such namespace: {:?}",
                 non_existent_namespace_ident
             ),
         );
@@ -1429,7 +1445,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => No such table: {:?}",
+                "TableNotFound => No such table: {:?}",
                 non_existent_table_ident
             ),
         );
@@ -1453,10 +1469,12 @@ mod tests {
         create_namespace(&catalog, &namespace_ident).await;
         let non_existent_table_ident = TableIdent::new(namespace_ident.clone(), "tbl1".into());
 
-        assert!(!catalog
-            .table_exists(&non_existent_table_ident)
-            .await
-            .unwrap());
+        assert!(
+            !catalog
+                .table_exists(&non_existent_table_ident)
+                .await
+                .unwrap()
+        );
     }
 
     #[tokio::test]
@@ -1472,10 +1490,12 @@ mod tests {
         assert!(catalog.table_exists(&table_ident).await.unwrap());
 
         let non_existent_table_ident = TableIdent::new(namespace_ident_a_b.clone(), "tbl2".into());
-        assert!(!catalog
-            .table_exists(&non_existent_table_ident)
-            .await
-            .unwrap());
+        assert!(
+            !catalog
+                .table_exists(&non_existent_table_ident)
+                .await
+                .unwrap()
+        );
     }
 
     #[tokio::test]
@@ -1493,7 +1513,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => No such namespace: {:?}",
+                "NamespaceNotFound => No such namespace: {:?}",
                 non_existent_namespace_ident
             ),
         );
@@ -1608,7 +1628,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => No such namespace: {:?}",
+                "NamespaceNotFound => No such namespace: {:?}",
                 non_existent_src_namespace_ident
             ),
         );
@@ -1632,7 +1652,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => No such namespace: {:?}",
+                "NamespaceNotFound => No such namespace: {:?}",
                 non_existent_dst_namespace_ident
             ),
         );
@@ -1652,7 +1672,7 @@ mod tests {
                 .await
                 .unwrap_err()
                 .to_string(),
-            format!("Unexpected => No such table: {:?}", src_table_ident),
+            format!("TableNotFound => No such table: {:?}", src_table_ident),
         );
     }
 
@@ -1672,7 +1692,7 @@ mod tests {
                 .unwrap_err()
                 .to_string(),
             format!(
-                "Unexpected => Cannot create table {:? }. Table already exists.",
+                "TableAlreadyExists => Cannot create table {:? }. Table already exists.",
                 &dst_table_ident
             ),
         );
