@@ -20,4 +20,7 @@
 #![deny(missing_docs)]
 
 mod catalog;
+mod client;
+mod types;
+
 pub use catalog::*;
