@@ -18,19 +18,19 @@
 //! Conversion between iceberg and avro schema.
 use std::collections::BTreeMap;
 
+use apache_avro::Schema as AvroSchema;
 use apache_avro::schema::{
     ArraySchema, DecimalSchema, FixedSchema, MapSchema, Name, RecordField as AvroRecordField,
     RecordFieldOrder, RecordSchema, UnionSchema,
 };
-use apache_avro::Schema as AvroSchema;
 use itertools::{Either, Itertools};
 use serde_json::{Number, Value};
 
 use crate::spec::{
-    visit_schema, ListType, MapType, NestedField, NestedFieldRef, PrimitiveType, Schema,
-    SchemaVisitor, StructType, Type,
+    ListType, MapType, NestedField, NestedFieldRef, PrimitiveType, Schema, SchemaVisitor,
+    StructType, Type, visit_schema,
 };
-use crate::{ensure_data_valid, Error, ErrorKind, Result};
+use crate::{Error, ErrorKind, Result, ensure_data_valid};
 
 const ELEMENT_ID: &str = "element-id";
 const FILED_ID_PROP: &str = "field-id";
@@ -442,13 +442,14 @@ impl AvroSchemaVisitor for AvroSchemaToSchema {
         field_types: Vec<Option<Type>>,
     ) -> Result<Option<Type>> {
         let mut fields = Vec::with_capacity(field_types.len());
-        for (avro_field, typ) in record.fields.iter().zip_eq(field_types) {
+        for (avro_field, field_type) in record.fields.iter().zip_eq(field_types) {
             let field_id =
                 Self::get_element_id_from_attributes(&avro_field.custom_attributes, FILED_ID_PROP)?;
 
             let optional = is_avro_optional(&avro_field.schema);
 
-            let mut field = NestedField::new(field_id, &avro_field.name, typ.unwrap(), !optional);
+            let mut field =
+                NestedField::new(field_id, &avro_field.name, field_type.unwrap(), !optional);
 
             if let Some(doc) = &avro_field.doc {
                 field = field.with_doc(doc);
@@ -514,7 +515,7 @@ impl AvroSchemaVisitor for AvroSchemaToSchema {
     }
 
     fn primitive(&mut self, schema: &AvroSchema) -> Result<Option<Type>> {
-        let typ = match schema {
+        let schema_type = match schema {
             AvroSchema::Decimal(decimal) => {
                 Type::decimal(decimal.precision as u32, decimal.scale as u32)?
             }
@@ -544,7 +545,7 @@ impl AvroSchemaVisitor for AvroSchemaToSchema {
                                 format!(
                                     "Logical type {ty} is not support in iceberg primitive type.",
                                 ),
-                            ))
+                            ));
                         }
                     }
                 } else {
@@ -557,11 +558,11 @@ impl AvroSchemaVisitor for AvroSchemaToSchema {
                 return Err(Error::new(
                     ErrorKind::Unexpected,
                     "Unable to convert avro {schema} to iceberg primitive type.",
-                ))
+                ));
             }
         };
 
-        Ok(Some(typ))
+        Ok(Some(schema_type))
     }
 
     fn map_array(
@@ -610,15 +611,16 @@ impl AvroSchemaVisitor for AvroSchemaToSchema {
 pub(crate) fn avro_schema_to_schema(avro_schema: &AvroSchema) -> Result<Schema> {
     if let AvroSchema::Record(_) = avro_schema {
         let mut converter = AvroSchemaToSchema;
-        let typ = visit(avro_schema, &mut converter)?.expect("Iceberg schema should not be none.");
-        if let Type::Struct(s) = typ {
+        let schema_type =
+            visit(avro_schema, &mut converter)?.expect("Iceberg schema should not be none.");
+        if let Type::Struct(s) = schema_type {
             Schema::builder()
                 .with_fields(s.fields().iter().cloned())
                 .build()
         } else {
             Err(Error::new(
                 ErrorKind::Unexpected,
-                format!("Expected to convert avro record schema to struct type, but {typ}"),
+                format!("Expected to convert avro record schema to struct type, but {schema_type}"),
             ))
         }
     } else {
@@ -634,8 +636,8 @@ mod tests {
     use std::fs::read_to_string;
     use std::sync::Arc;
 
-    use apache_avro::schema::{Namespace, UnionSchema};
     use apache_avro::Schema as AvroSchema;
+    use apache_avro::schema::{Namespace, UnionSchema};
 
     use super::*;
     use crate::avro::schema::AvroSchemaToSchema;
@@ -781,20 +783,22 @@ mod tests {
 
         let iceberg_schema = {
             Schema::builder()
-                .with_fields(vec![NestedField::required(
-                    100,
-                    "array_with_string",
-                    ListType {
-                        element_field: NestedField::list_element(
-                            101,
-                            PrimitiveType::String.into(),
-                            true,
-                        )
+                .with_fields(vec![
+                    NestedField::required(
+                        100,
+                        "array_with_string",
+                        ListType {
+                            element_field: NestedField::list_element(
+                                101,
+                                PrimitiveType::String.into(),
+                                true,
+                            )
+                            .into(),
+                        }
                         .into(),
-                    }
+                    )
                     .into(),
-                )
-                .into()])
+                ])
                 .build()
                 .unwrap()
         };
@@ -830,20 +834,22 @@ mod tests {
 
         let iceberg_schema = {
             Schema::builder()
-                .with_fields(vec![NestedField::required(
-                    100,
-                    "array_with_string",
-                    ListType {
-                        element_field: NestedField::list_element(
-                            101,
-                            PrimitiveType::String.into(),
-                            true,
-                        )
+                .with_fields(vec![
+                    NestedField::required(
+                        100,
+                        "array_with_string",
+                        ListType {
+                            element_field: NestedField::list_element(
+                                101,
+                                PrimitiveType::String.into(),
+                                true,
+                            )
+                            .into(),
+                        }
                         .into(),
-                    }
+                    )
                     .into(),
-                )
-                .into()])
+                ])
                 .build()
                 .unwrap()
         };
@@ -893,34 +899,36 @@ mod tests {
 
         let iceberg_schema = {
             Schema::builder()
-                .with_fields(vec![NestedField::required(
-                    100,
-                    "array_with_record",
-                    ListType {
-                        element_field: NestedField::list_element(
-                            101,
-                            StructType::new(vec![
-                                NestedField::required(
-                                    102,
-                                    "contains_null",
-                                    PrimitiveType::Boolean.into(),
-                                )
+                .with_fields(vec![
+                    NestedField::required(
+                        100,
+                        "array_with_record",
+                        ListType {
+                            element_field: NestedField::list_element(
+                                101,
+                                StructType::new(vec![
+                                    NestedField::required(
+                                        102,
+                                        "contains_null",
+                                        PrimitiveType::Boolean.into(),
+                                    )
+                                    .into(),
+                                    NestedField::optional(
+                                        103,
+                                        "contains_nan",
+                                        PrimitiveType::Boolean.into(),
+                                    )
+                                    .into(),
+                                ])
                                 .into(),
-                                NestedField::optional(
-                                    103,
-                                    "contains_nan",
-                                    PrimitiveType::Boolean.into(),
-                                )
-                                .into(),
-                            ])
+                                true,
+                            )
                             .into(),
-                            true,
-                        )
+                        }
                         .into(),
-                    }
+                    )
                     .into(),
-                )
-                .into()])
+                ])
                 .build()
                 .unwrap()
         };
