@@ -18,7 +18,7 @@
 //! Catalog API for Apache Iceberg
 
 use std::collections::HashMap;
-use std::fmt::Debug;
+use std::fmt::{Debug, Display};
 use std::mem::take;
 use std::ops::Deref;
 
@@ -41,7 +41,7 @@ use crate::{Error, ErrorKind, Result};
 pub trait Catalog: Debug + Sync + Send {
     /// List namespaces inside the catalog.
     async fn list_namespaces(&self, parent: Option<&NamespaceIdent>)
-        -> Result<Vec<NamespaceIdent>>;
+    -> Result<Vec<NamespaceIdent>>;
 
     /// Create a new namespace inside the catalog.
     async fn create_namespace(
@@ -67,7 +67,7 @@ pub trait Catalog: Debug + Sync + Send {
         properties: HashMap<String, String>,
     ) -> Result<()>;
 
-    /// Drop a namespace from the catalog.
+    /// Drop a namespace from the catalog, or returns error if it doesn't exist.
     async fn drop_namespace(&self, namespace: &NamespaceIdent) -> Result<()>;
 
     /// List tables from namespace.
@@ -83,7 +83,7 @@ pub trait Catalog: Debug + Sync + Send {
     /// Load table from the catalog.
     async fn load_table(&self, table: &TableIdent) -> Result<Table>;
 
-    /// Drop a table from the catalog.
+    /// Drop a table from the catalog, or returns error if it doesn't exist.
     async fn drop_table(&self, table: &TableIdent) -> Result<()>;
 
     /// Check if a table exists in the catalog.
@@ -192,6 +192,12 @@ impl Namespace {
     }
 }
 
+impl Display for NamespaceIdent {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "{}", self.0.join("."))
+    }
+}
+
 /// TableIdent represents the identifier of a table in the catalog.
 #[derive(Serialize, Deserialize, Debug, Clone, PartialEq, Eq, Hash)]
 pub struct TableIdent {
@@ -232,6 +238,12 @@ impl TableIdent {
     }
 }
 
+impl Display for TableIdent {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "{}.{}", self.namespace, self.name)
+    }
+}
+
 /// TableCreation represents the creation of a table in the catalog.
 #[derive(Debug, TypedBuilder)]
 pub struct TableCreation {
@@ -249,11 +261,17 @@ pub struct TableCreation {
     #[builder(default, setter(strip_option(fallback = sort_order_opt)))]
     pub sort_order: Option<SortOrder>,
     /// The properties of the table.
-    #[builder(default)]
+    #[builder(default, setter(transform = |props: impl IntoIterator<Item=(String, String)>| {
+        props.into_iter().collect()
+    }))]
     pub properties: HashMap<String, String>,
 }
 
 /// TableCommit represents the commit of a table in the catalog.
+///
+/// The builder is marked as private since it's dangerous and error-prone to construct
+/// [`TableCommit`] directly.
+/// Users are supposed to use [`crate::transaction::Transaction`] to update table.
 #[derive(Debug, TypedBuilder)]
 #[builder(build_method(vis = "pub(crate)"))]
 pub struct TableCommit {
@@ -285,7 +303,7 @@ impl TableCommit {
 }
 
 /// TableRequirement represents a requirement for a table in the catalog.
-#[derive(Debug, Serialize, Deserialize, PartialEq)]
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
 #[serde(tag = "type")]
 pub enum TableRequirement {
     /// The table must not already exist; used for create transactions
@@ -349,6 +367,7 @@ pub enum TableRequirement {
 /// TableUpdate represents an update to a table in the catalog.
 #[derive(Debug, Serialize, Deserialize, PartialEq, Clone)]
 #[serde(tag = "action", rename_all = "kebab-case")]
+#[allow(clippy::large_enum_variant)]
 pub enum TableUpdate {
     /// Upgrade table's format version
     #[serde(rename_all = "kebab-case")]
@@ -470,6 +489,12 @@ pub enum TableUpdate {
         /// Snapshot id to remove partition statistics for.
         snapshot_id: i64,
     },
+    /// Remove schemas
+    #[serde(rename_all = "kebab-case")]
+    RemoveSchemas {
+        /// Schema IDs to remove.
+        schema_ids: Vec<i32>,
+    },
 }
 
 impl TableUpdate {
@@ -513,6 +538,7 @@ impl TableUpdate {
             TableUpdate::RemovePartitionStatistics { snapshot_id } => {
                 Ok(builder.remove_partition_statistics(snapshot_id))
             }
+            TableUpdate::RemoveSchemas { schema_ids } => builder.remove_schemas(&schema_ids),
         }
     }
 }
@@ -738,6 +764,7 @@ pub struct ViewCreation {
 /// ViewUpdate represents an update to a view in the catalog.
 #[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
 #[serde(tag = "action", rename_all = "kebab-case")]
+#[allow(clippy::large_enum_variant)]
 pub enum ViewUpdate {
     /// Assign a new UUID to the view
     #[serde(rename_all = "kebab-case")]
@@ -845,17 +872,18 @@ mod tests {
     use std::collections::HashMap;
     use std::fmt::Debug;
 
-    use serde::de::DeserializeOwned;
     use serde::Serialize;
+    use serde::de::DeserializeOwned;
     use uuid::uuid;
 
     use super::ViewUpdate;
     use crate::spec::{
-        BlobMetadata, FormatVersion, NestedField, NullOrder, Operation, PartitionStatisticsFile,
-        PrimitiveType, Schema, Snapshot, SnapshotReference, SnapshotRetention, SortDirection,
-        SortField, SortOrder, SqlViewRepresentation, StatisticsFile, Summary, TableMetadata,
-        TableMetadataBuilder, Transform, Type, UnboundPartitionSpec, ViewFormatVersion,
-        ViewRepresentation, ViewRepresentations, ViewVersion, MAIN_BRANCH,
+        BlobMetadata, FormatVersion, MAIN_BRANCH, NestedField, NullOrder, Operation,
+        PartitionStatisticsFile, PrimitiveType, Schema, Snapshot, SnapshotReference,
+        SnapshotRetention, SortDirection, SortField, SortOrder, SqlViewRepresentation,
+        StatisticsFile, Summary, TableMetadata, TableMetadataBuilder, Transform, Type,
+        UnboundPartitionSpec, ViewFormatVersion, ViewRepresentation, ViewRepresentations,
+        ViewVersion,
     };
     use crate::{NamespaceIdent, TableCreation, TableIdent, TableRequirement, TableUpdate};
 
@@ -880,6 +908,26 @@ mod tests {
         assert_eq!(table_id, TableIdent::from_strs(vec!["ns1", "t1"]).unwrap());
     }
 
+    #[test]
+    fn test_table_creation_iterator_properties() {
+        let builder = TableCreation::builder()
+            .name("table".to_string())
+            .schema(Schema::builder().build().unwrap());
+
+        fn s(k: &str, v: &str) -> (String, String) {
+            (k.to_string(), v.to_string())
+        }
+
+        let table_creation = builder
+            .properties([s("key", "value"), s("foo", "bar")])
+            .build();
+
+        assert_eq!(
+            HashMap::from([s("key", "value"), s("foo", "bar")]),
+            table_creation.properties
+        );
+    }
+
     fn test_serde_json<T: Serialize + DeserializeOwned + PartialEq + Debug>(
         json: impl ToString,
         expected: T,
@@ -1113,7 +1161,7 @@ mod tests {
 {
     "type": "assert-ref-snapshot-id",
     "ref": "snapshot-name",
-    "snapshot-id": null 
+    "snapshot-id": null
 }
         "#,
             TableRequirement::RefSnapshotIdMatch {
@@ -1233,7 +1281,7 @@ mod tests {
 {
     "action": "assign-uuid",
     "uuid": "2cc52516-5e73-41f2-b139-545d41a4e151"
-}        
+}
         "#,
             TableUpdate::AssignUuid {
                 uuid: uuid!("2cc52516-5e73-41f2-b139-545d41a4e151"),
@@ -1248,7 +1296,7 @@ mod tests {
 {
     "action": "upgrade-format-version",
     "format-version": 2
-}        
+}
         "#,
             TableUpdate::UpgradeFormatVersion {
                 format_version: FormatVersion::V2,
@@ -1557,7 +1605,7 @@ mod tests {
         1,
         2
     ]
-}  
+}
         "#;
 
         let update = TableUpdate::RemoveSnapshots {
@@ -1617,7 +1665,7 @@ mod tests {
     "min-snapshots-to-keep": 2,
     "max-snapshot-age-ms": 3,
     "max-ref-age-ms": 4
-}        
+}
         "#;
 
         let update = TableUpdate::SetSnapshotRef {
@@ -1644,7 +1692,7 @@ mod tests {
         "prop1": "v1",
         "prop2": "v2"
     }
-}        
+}
         "#;
 
         let update = TableUpdate::SetProperties {
@@ -1668,7 +1716,7 @@ mod tests {
         "prop1",
         "prop2"
     ]
-}        
+}
         "#;
 
         let update = TableUpdate::RemoveProperties {
@@ -1730,7 +1778,7 @@ mod tests {
 {
     "action": "assign-uuid",
     "uuid": "2cc52516-5e73-41f2-b139-545d41a4e151"
-}        
+}
         "#,
             ViewUpdate::AssignUuid {
                 uuid: uuid!("2cc52516-5e73-41f2-b139-545d41a4e151"),
@@ -1745,7 +1793,7 @@ mod tests {
 {
     "action": "upgrade-format-version",
     "format-version": 1
-}        
+}
         "#,
             ViewUpdate::UpgradeFormatVersion {
                 format_version: ViewFormatVersion::V1,
@@ -1813,7 +1861,7 @@ mod tests {
 {
     "action": "set-location",
     "location": "s3://db/view"
-}        
+}
         "#,
             ViewUpdate::SetLocation {
                 location: "s3://db/view".to_string(),
@@ -1831,7 +1879,7 @@ mod tests {
         "prop1": "v1",
         "prop2": "v2"
     }
-}        
+}
         "#,
             ViewUpdate::SetProperties {
                 updates: vec![
@@ -1854,7 +1902,7 @@ mod tests {
         "prop1",
         "prop2"
     ]
-}        
+}
         "#,
             ViewUpdate::RemoveProperties {
                 removals: vec!["prop1".to_string(), "prop2".to_string()],
@@ -1883,7 +1931,7 @@ mod tests {
               "dialect" : "spark"
             } ]
     }
-}        
+}
         "#,
             ViewUpdate::AddViewVersion {
                 view_version: ViewVersion::builder()
@@ -1913,7 +1961,7 @@ mod tests {
 {
     "action": "set-current-view-version",
     "view-version-id": 1
-}        
+}
         "#,
             ViewUpdate::SetCurrentViewVersion { view_version_id: 1 },
         );
@@ -1926,7 +1974,7 @@ mod tests {
 {
     "action": "remove-partition-specs",
     "spec-ids": [1, 2]
-}        
+}
         "#,
             TableUpdate::RemovePartitionSpecs {
                 spec_ids: vec![1, 2],
@@ -1960,7 +2008,7 @@ mod tests {
                                 }
                         ]
                 }
-        } 
+        }
         "#,
             TableUpdate::SetStatistics {
                 statistics: StatisticsFile {
@@ -1990,7 +2038,7 @@ mod tests {
         {
                 "action": "remove-statistics",
                 "snapshot-id": 1940541653261589030
-        } 
+        }
         "#,
             TableUpdate::RemoveStatistics {
                 snapshot_id: 1940541653261589030,
@@ -2035,4 +2083,19 @@ mod tests {
             },
         )
     }
+
+    #[test]
+    fn test_remove_schema_update() {
+        test_serde_json(
+            r#"
+                {
+                    "action": "remove-schemas",
+                    "schema-ids": [1, 2]
+                }        
+            "#,
+            TableUpdate::RemoveSchemas {
+                schema_ids: vec![1, 2],
+            },
+        );
+    }
 }
