@@ -22,3 +22,5 @@ pub(crate) mod inclusive_projection;
 pub(crate) mod manifest_evaluator;
 pub(crate) mod page_index_evaluator;
 pub(crate) mod row_group_metrics_evaluator;
+pub(crate) mod strict_metrics_evaluator;
+pub(crate) mod strict_projection;
