@@ -22,8 +22,8 @@
 //! We provided a `FileIOBuilder` to build `FileIO` from scratch. For example:
 //!
 //! ```rust
-//! use iceberg::io::{FileIOBuilder, S3_REGION};
 //! use iceberg::Result;
+//! use iceberg::io::{FileIOBuilder, S3_REGION};
 //!
 //! # fn test() -> Result<()> {
 //! // Build a memory file io.
@@ -41,8 +41,8 @@
 //! Or you can pass a path to ask `FileIO` to infer schema for you:
 //!
 //! ```rust
-//! use iceberg::io::{FileIO, S3_REGION};
 //! use iceberg::Result;
+//! use iceberg::io::{FileIO, S3_REGION};
 //!
 //! # fn test() -> Result<()> {
 //! // Build a memory file io.
@@ -88,3 +88,12 @@ use storage_fs::*;
 mod storage_gcs;
 #[cfg(feature = "storage-gcs")]
 pub use storage_gcs::*;
+
+#[cfg(feature = "storage-oss")]
+mod storage_oss;
+#[cfg(feature = "storage-oss")]
+pub use storage_oss::*;
+
+pub(crate) fn is_truthy(value: &str) -> bool {
+    ["true", "t", "1", "on"].contains(&value.to_lowercase().as_str())
+}
