@@ -17,11 +17,11 @@
 
 use std::collections::HashMap;
 
-use opendal::raw::HttpClient;
 use opendal::services::S3Config;
 use opendal::{Configurator, Operator};
 use url::Url;
 
+use crate::io::is_truthy;
 use crate::{Error, ErrorKind, Result};
 
 /// Following are arguments for [s3 file io](https://py.iceberg.apache.org/configuration/#s3).
@@ -66,10 +66,6 @@ pub const S3_DISABLE_EC2_METADATA: &str = "s3.disable-ec2-metadata";
 /// Option to skip loading configuration from config file and the env.
 pub const S3_DISABLE_CONFIG_LOAD: &str = "s3.disable-config-load";
 
-fn is_truthy(value: &str) -> bool {
-    ["true", "t", "1", "on"].contains(&value)
-}
-
 /// Parse iceberg props to s3 config.
 pub(crate) fn s3_config_parse(mut m: HashMap<String, String>) -> Result<S3Config> {
     let mut cfg = S3Config::default();
@@ -92,9 +88,7 @@ pub(crate) fn s3_config_parse(mut m: HashMap<String, String>) -> Result<S3Config
         cfg.region = Some(region);
     };
     if let Some(path_style_access) = m.remove(S3_PATH_STYLE_ACCESS) {
-        if is_truthy(path_style_access.to_lowercase().as_str()) {
-            cfg.enable_virtual_host_style = true;
-        }
+        cfg.enable_virtual_host_style = !is_truthy(path_style_access.to_lowercase().as_str());
     };
     if let Some(arn) = m.remove(S3_ASSUME_ROLE_ARN) {
         cfg.role_arn = Some(arn);
@@ -157,11 +151,7 @@ pub(crate) fn s3_config_parse(mut m: HashMap<String, String>) -> Result<S3Config
 }
 
 /// Build new opendal operator from give path.
-pub(crate) fn s3_config_build(
-    client: &reqwest::Client,
-    cfg: &S3Config,
-    path: &str,
-) -> Result<Operator> {
+pub(crate) fn s3_config_build(cfg: &S3Config, path: &str) -> Result<Operator> {
     let url = Url::parse(path)?;
     let bucket = url.host_str().ok_or_else(|| {
         Error::new(
@@ -174,9 +164,7 @@ pub(crate) fn s3_config_build(
         .clone()
         .into_builder()
         // Set bucket name.
-        .bucket(bucket)
-        // Set http client we want to use.
-        .http_client(HttpClient::with(client.clone()));
+        .bucket(bucket);
 
     Ok(Operator::new(builder)?.finish())
 }
