@@ -21,7 +21,9 @@
 //!
 //! ## Scan A Table
 //!
-//! ```rust, no_run
+//! ```rust, ignore
+//! // This example uses `iceberg_catalog_memory`, which isn't enabled by default.
+//! // To run this, add `iceberg-catalog-memory` as a dependency in your Cargo.toml.
 //! use futures::TryStreamExt;
 //! use iceberg::io::{FileIO, FileIOBuilder};
 //! use iceberg::{Catalog, Result, TableIdent};
@@ -70,9 +72,11 @@ pub use catalog::{
 pub mod table;
 
 mod avro;
+pub mod cache;
 pub mod io;
 pub mod spec;
 
+pub mod inspect;
 pub mod scan;
 
 pub mod expr;
@@ -82,7 +86,9 @@ pub mod transform;
 mod runtime;
 
 pub mod arrow;
+pub(crate) mod delete_file_index;
 mod utils;
 pub mod writer;
 
-mod puffin;
+mod delete_vector;
+pub mod puffin;
