@@ -21,7 +21,7 @@ use std::collections::HashMap;
 use std::str::FromStr;
 
 use apache_avro::types::Value;
-use apache_avro::{from_value, Reader, Writer};
+use apache_avro::{Reader, Writer, from_value};
 use bytes::Bytes;
 
 use self::_const_schema::{MANIFEST_LIST_AVRO_SCHEMA_V1, MANIFEST_LIST_AVRO_SCHEMA_V2};
@@ -507,7 +507,7 @@ mod _const_schema {
 }
 
 /// Entry in a manifest list.
-#[derive(Debug, PartialEq, Clone)]
+#[derive(Debug, PartialEq, Clone, Eq, Hash)]
 pub struct ManifestFile {
     /// field: 500
     ///
@@ -587,17 +587,22 @@ pub struct ManifestFile {
 impl ManifestFile {
     /// Checks if the manifest file has any added files.
     pub fn has_added_files(&self) -> bool {
-        self.added_files_count.is_none() || self.added_files_count.unwrap() > 0
+        self.added_files_count.map(|c| c > 0).unwrap_or(true)
+    }
+
+    /// Checks whether this manifest contains entries with DELETED status.
+    pub fn has_deleted_files(&self) -> bool {
+        self.deleted_files_count.map(|c| c > 0).unwrap_or(true)
     }
 
     /// Checks if the manifest file has any existed files.
     pub fn has_existing_files(&self) -> bool {
-        self.existing_files_count.is_none() || self.existing_files_count.unwrap() > 0
+        self.existing_files_count.map(|c| c > 0).unwrap_or(true)
     }
 }
 
 /// The type of files tracked by the manifest, either data or delete files; Data(0) for all v1 manifests
-#[derive(Debug, PartialEq, Clone, Eq)]
+#[derive(Debug, PartialEq, Clone, Copy, Eq, Hash)]
 pub enum ManifestContentType {
     /// The manifest content is data.
     Data = 0,
@@ -668,7 +673,7 @@ impl ManifestFile {
 /// Field summary for partition field in the spec.
 ///
 /// Each field in the list corresponds to a field in the manifest file’s partition spec.
-#[derive(Debug, PartialEq, Eq, Clone, Default)]
+#[derive(Debug, PartialEq, Eq, Clone, Default, Hash)]
 pub struct FieldSummary {
     /// field: 509
     ///
@@ -698,9 +703,9 @@ pub(super) mod _serde {
     use serde_derive::{Deserialize, Serialize};
 
     use super::ManifestFile;
+    use crate::Error;
     use crate::error::Result;
     use crate::spec::{Datum, PrimitiveType, StructType};
-    use crate::Error;
 
     #[derive(Debug, Serialize, Deserialize, PartialEq, Eq)]
     #[serde(transparent)]
