@@ -20,11 +20,13 @@
  */
 use std::sync::Arc;
 
+use itertools::Itertools;
 use serde::{Deserialize, Serialize};
 use typed_builder::TypedBuilder;
 
 use super::transform::Transform;
 use super::{NestedField, Schema, SchemaRef, StructType};
+use crate::spec::Struct;
 use crate::{Error, ErrorKind, Result};
 
 pub(crate) const UNPARTITIONED_LAST_ASSIGNED_ID: i32 = 999;
@@ -152,6 +154,26 @@ impl PartitionSpec {
 
         true
     }
+
+    pub(crate) fn partition_to_path(&self, data: &Struct, schema: SchemaRef) -> String {
+        let partition_type = self.partition_type(&schema).unwrap();
+        let field_types = partition_type.fields();
+
+        self.fields
+            .iter()
+            .enumerate()
+            .map(|(i, field)| {
+                let value = data[i].as_ref();
+                format!(
+                    "{}={}",
+                    field.name,
+                    field
+                        .transform
+                        .to_human_string(&field_types[i].field_type, value)
+                )
+            })
+            .join("/")
+    }
 }
 
 /// Reference to [`UnboundPartitionSpec`].
@@ -616,12 +638,14 @@ trait CorePartitionSpecValidator {
 
         if let Some(collision) = collision {
             Err(Error::new(
-                    ErrorKind::DataInvalid,
-                    format!(
-                        "Cannot add redundant partition with source id `{}` and transform `{}`. A partition with the same source id and transform already exists with name `{}`",
-                        source_id, transform.dedup_name(), collision.name
-                    ),
-                ))
+                ErrorKind::DataInvalid,
+                format!(
+                    "Cannot add redundant partition with source id `{}` and transform `{}`. A partition with the same source id and transform already exists with name `{}`",
+                    source_id,
+                    transform.dedup_name(),
+                    collision.name
+                ),
+            ))
         } else {
             Ok(())
         }
@@ -660,7 +684,7 @@ impl CorePartitionSpecValidator for UnboundPartitionSpecBuilder {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::spec::{PrimitiveType, Type};
+    use crate::spec::{Literal, PrimitiveType, Type};
 
     #[test]
     fn test_partition_spec() {
@@ -1176,24 +1200,20 @@ mod tests {
         });
         assert_eq!(
             spec.partition_type(&schema).unwrap(),
-            StructType::new(vec![NestedField::optional(
-                1000,
-                "id_bucket[16]",
-                Type::Primitive(PrimitiveType::Int)
-            )
-            .into()])
+            StructType::new(vec![
+                NestedField::optional(1000, "id_bucket[16]", Type::Primitive(PrimitiveType::Int))
+                    .into()
+            ])
         )
     }
 
     #[test]
     fn test_collision_with_schema_name() {
         let schema = Schema::builder()
-            .with_fields(vec![NestedField::required(
-                1,
-                "id",
-                Type::Primitive(crate::spec::PrimitiveType::Int),
-            )
-            .into()])
+            .with_fields(vec![
+                NestedField::required(1, "id", Type::Primitive(crate::spec::PrimitiveType::Int))
+                    .into(),
+            ])
             .build()
             .unwrap();
 
@@ -1340,12 +1360,10 @@ mod tests {
     #[test]
     fn test_builder_incompatible_transforms_disallowed() {
         let schema = Schema::builder()
-            .with_fields(vec![NestedField::required(
-                1,
-                "id",
-                Type::Primitive(crate::spec::PrimitiveType::Int),
-            )
-            .into()])
+            .with_fields(vec![
+                NestedField::required(1, "id", Type::Primitive(crate::spec::PrimitiveType::Int))
+                    .into(),
+            ])
             .build()
             .unwrap();
 
@@ -1430,12 +1448,10 @@ mod tests {
     #[test]
     fn test_not_compatible_with_transform_different() {
         let schema = Schema::builder()
-            .with_fields(vec![NestedField::required(
-                1,
-                "id",
-                Type::Primitive(crate::spec::PrimitiveType::Int),
-            )
-            .into()])
+            .with_fields(vec![
+                NestedField::required(1, "id", Type::Primitive(crate::spec::PrimitiveType::Int))
+                    .into(),
+            ])
             .build()
             .unwrap();
 
@@ -1733,4 +1749,30 @@ mod tests {
         assert_eq!(1002, spec.fields[1].field_id);
         assert!(!spec.has_sequential_ids());
     }
+
+    #[test]
+    fn test_partition_to_path() {
+        let schema = Schema::builder()
+            .with_fields(vec![
+                NestedField::required(1, "id", Type::Primitive(PrimitiveType::Int)).into(),
+                NestedField::required(2, "name", Type::Primitive(PrimitiveType::String)).into(),
+            ])
+            .build()
+            .unwrap();
+
+        let spec = PartitionSpec::builder(schema.clone())
+            .add_partition_field("id", "id", Transform::Identity)
+            .unwrap()
+            .add_partition_field("name", "name", Transform::Identity)
+            .unwrap()
+            .build()
+            .unwrap();
+
+        let data = Struct::from_iter([Some(Literal::int(42)), Some(Literal::string("alice"))]);
+
+        assert_eq!(
+            spec.partition_to_path(&data, schema.into()),
+            "id=42/name=\"alice\""
+        );
+    }
 }
