@@ -53,6 +53,7 @@ pub struct EqualityDeleteWriterConfig {
     // Projector used to project the data chunk into specific fields.
     projector: RecordBatchProjector,
     partition_value: Struct,
+    partition_spec_id: i32,
 }
 
 impl EqualityDeleteWriterConfig {
@@ -61,19 +62,19 @@ impl EqualityDeleteWriterConfig {
         equality_ids: Vec<i32>,
         original_schema: SchemaRef,
         partition_value: Option<Struct>,
+        partition_spec_id: i32,
     ) -> Result<Self> {
         let original_arrow_schema = Arc::new(schema_to_arrow_schema(&original_schema)?);
         let projector = RecordBatchProjector::new(
             original_arrow_schema,
             &equality_ids,
             // The following rule comes from https://iceberg.apache.org/spec/#identifier-field-ids
+            // and https://iceberg.apache.org/spec/#equality-delete-files
             // - The identifier field ids must be used for primitive types.
             // - The identifier field ids must not be used for floating point types or nullable fields.
-            // - The identifier field ids can be nested field of struct but not nested field of nullable struct.
             |field| {
                 // Only primitive type is allowed to be used for identifier field ids
-                if field.is_nullable()
-                    || field.data_type().is_nested()
+                if field.data_type().is_nested()
                     || matches!(
                         field.data_type(),
                         DataType::Float16 | DataType::Float32 | DataType::Float64
@@ -92,12 +93,13 @@ impl EqualityDeleteWriterConfig {
                         .map_err(|e| Error::new(ErrorKind::Unexpected, e.to_string()))?,
                 ))
             },
-            |field: &Field| !field.is_nullable(),
+            |_field: &Field| true,
         )?;
         Ok(Self {
             equality_ids,
             projector,
             partition_value: partition_value.unwrap_or(Struct::empty()),
+            partition_spec_id,
         })
     }
 
@@ -117,6 +119,7 @@ impl<B: FileWriterBuilder> IcebergWriterBuilder for EqualityDeleteFileWriterBuil
             projector: self.config.projector,
             equality_ids: self.config.equality_ids,
             partition_value: self.config.partition_value,
+            partition_spec_id: self.config.partition_spec_id,
         })
     }
 }
@@ -128,12 +131,13 @@ pub struct EqualityDeleteFileWriter<B: FileWriterBuilder> {
     projector: RecordBatchProjector,
     equality_ids: Vec<i32>,
     partition_value: Struct,
+    partition_spec_id: i32,
 }
 
 #[async_trait::async_trait]
 impl<B: FileWriterBuilder> IcebergWriter for EqualityDeleteFileWriter<B> {
     async fn write(&mut self, batch: RecordBatch) -> Result<()> {
-        let batch = self.projector.project_bacth(batch)?;
+        let batch = self.projector.project_batch(batch)?;
         if let Some(writer) = self.inner_writer.as_mut() {
             writer.write(&batch).await
         } else {
@@ -154,6 +158,7 @@ impl<B: FileWriterBuilder> IcebergWriter for EqualityDeleteFileWriter<B> {
                     res.content(crate::spec::DataContentType::EqualityDeletes);
                     res.equality_ids(self.equality_ids.iter().copied().collect_vec());
                     res.partition(self.partition_value.clone());
+                    res.partition_spec_id(self.partition_spec_id);
                     res.build().expect("msg")
                 })
                 .collect_vec())
@@ -168,13 +173,16 @@ impl<B: FileWriterBuilder> IcebergWriter for EqualityDeleteFileWriter<B> {
 
 #[cfg(test)]
 mod test {
+    use std::collections::HashMap;
     use std::sync::Arc;
 
     use arrow_array::types::Int32Type;
     use arrow_array::{ArrayRef, BooleanArray, Int32Array, Int64Array, RecordBatch, StructArray};
-    use arrow_schema::DataType;
+    use arrow_buffer::NullBuffer;
+    use arrow_schema::{DataType, Field, Fields};
     use arrow_select::concat::concat_batches;
     use itertools::Itertools;
+    use parquet::arrow::PARQUET_FIELD_ID_META_KEY;
     use parquet::arrow::arrow_reader::ParquetRecordBatchReaderBuilder;
     use parquet::file::properties::WriterProperties;
     use tempfile::TempDir;
@@ -189,9 +197,9 @@ mod test {
     use crate::writer::base_writer::equality_delete_writer::{
         EqualityDeleteFileWriterBuilder, EqualityDeleteWriterConfig,
     };
-    use crate::writer::file_writer::location_generator::test::MockLocationGenerator;
-    use crate::writer::file_writer::location_generator::DefaultFileNameGenerator;
     use crate::writer::file_writer::ParquetWriterBuilder;
+    use crate::writer::file_writer::location_generator::DefaultFileNameGenerator;
+    use crate::writer::file_writer::location_generator::test::MockLocationGenerator;
     use crate::writer::{IcebergWriter, IcebergWriterBuilder};
 
     async fn check_parquet_data_file_with_equality_delete_write(
@@ -288,12 +296,10 @@ mod test {
                 NestedField::required(
                     1,
                     "col1",
-                    Type::Struct(StructType::new(vec![NestedField::required(
-                        5,
-                        "sub_col",
-                        Type::Primitive(PrimitiveType::Int),
-                    )
-                    .into()])),
+                    Type::Struct(StructType::new(vec![
+                        NestedField::required(5, "sub_col", Type::Primitive(PrimitiveType::Int))
+                            .into(),
+                    ])),
                 )
                 .into(),
                 NestedField::required(2, "col2", Type::Primitive(PrimitiveType::String)).into(),
@@ -309,17 +315,21 @@ mod test {
                 NestedField::required(
                     4,
                     "col4",
-                    Type::Struct(StructType::new(vec![NestedField::required(
-                        7,
-                        "sub_col",
-                        Type::Struct(StructType::new(vec![NestedField::required(
-                            8,
-                            "sub_sub_col",
-                            Type::Primitive(PrimitiveType::Int),
+                    Type::Struct(StructType::new(vec![
+                        NestedField::required(
+                            7,
+                            "sub_col",
+                            Type::Struct(StructType::new(vec![
+                                NestedField::required(
+                                    8,
+                                    "sub_sub_col",
+                                    Type::Primitive(PrimitiveType::Int),
+                                )
+                                .into(),
+                            ])),
                         )
-                        .into()])),
-                    )
-                    .into()])),
+                        .into(),
+                    ])),
                 )
                 .into(),
             ])
@@ -385,7 +395,7 @@ mod test {
 
         let equality_ids = vec![0_i32, 8];
         let equality_config =
-            EqualityDeleteWriterConfig::new(equality_ids, Arc::new(schema), None).unwrap();
+            EqualityDeleteWriterConfig::new(equality_ids, Arc::new(schema), None, 0).unwrap();
         let delete_schema =
             arrow_schema_to_schema(equality_config.projected_arrow_schema_ref()).unwrap();
         let projector = equality_config.projector.clone();
@@ -409,7 +419,7 @@ mod test {
         let data_file = res.into_iter().next().unwrap();
 
         // check
-        let to_write_projected = projector.project_bacth(to_write)?;
+        let to_write_projected = projector.project_batch(to_write)?;
         check_parquet_data_file_with_equality_delete_write(
             &file_io,
             &data_file,
@@ -431,23 +441,27 @@ mod test {
                     NestedField::required(
                         3,
                         "col3",
-                        Type::Struct(StructType::new(vec![NestedField::required(
-                            4,
-                            "sub_col",
-                            Type::Primitive(PrimitiveType::Int),
-                        )
-                        .into()])),
+                        Type::Struct(StructType::new(vec![
+                            NestedField::required(
+                                4,
+                                "sub_col",
+                                Type::Primitive(PrimitiveType::Int),
+                            )
+                            .into(),
+                        ])),
                     )
                     .into(),
                     NestedField::optional(
                         5,
                         "col4",
-                        Type::Struct(StructType::new(vec![NestedField::required(
-                            6,
-                            "sub_col2",
-                            Type::Primitive(PrimitiveType::Int),
-                        )
-                        .into()])),
+                        Type::Struct(StructType::new(vec![
+                            NestedField::required(
+                                6,
+                                "sub_col2",
+                                Type::Primitive(PrimitiveType::Int),
+                            )
+                            .into(),
+                        ])),
                     )
                     .into(),
                     NestedField::required(
@@ -482,23 +496,19 @@ mod test {
                 .unwrap(),
         );
         // Float and Double are not allowed to be used for equality delete
-        assert!(EqualityDeleteWriterConfig::new(vec![0], schema.clone(), None).is_err());
-        assert!(EqualityDeleteWriterConfig::new(vec![1], schema.clone(), None).is_err());
-        // Int is nullable, not allowed to be used for equality delete
-        assert!(EqualityDeleteWriterConfig::new(vec![2], schema.clone(), None).is_err());
+        assert!(EqualityDeleteWriterConfig::new(vec![0], schema.clone(), None, 0).is_err());
+        assert!(EqualityDeleteWriterConfig::new(vec![1], schema.clone(), None, 0).is_err());
         // Struct is not allowed to be used for equality delete
-        assert!(EqualityDeleteWriterConfig::new(vec![3], schema.clone(), None).is_err());
+        assert!(EqualityDeleteWriterConfig::new(vec![3], schema.clone(), None, 0).is_err());
         // Nested field of struct is allowed to be used for equality delete
-        assert!(EqualityDeleteWriterConfig::new(vec![4], schema.clone(), None).is_ok());
-        // Nested field of optional struct is not allowed to be used for equality delete
-        assert!(EqualityDeleteWriterConfig::new(vec![6], schema.clone(), None).is_err());
+        assert!(EqualityDeleteWriterConfig::new(vec![4], schema.clone(), None, 0).is_ok());
         // Nested field of map is not allowed to be used for equality delete
-        assert!(EqualityDeleteWriterConfig::new(vec![7], schema.clone(), None).is_err());
-        assert!(EqualityDeleteWriterConfig::new(vec![8], schema.clone(), None).is_err());
-        assert!(EqualityDeleteWriterConfig::new(vec![9], schema.clone(), None).is_err());
+        assert!(EqualityDeleteWriterConfig::new(vec![7], schema.clone(), None, 0).is_err());
+        assert!(EqualityDeleteWriterConfig::new(vec![8], schema.clone(), None, 0).is_err());
+        assert!(EqualityDeleteWriterConfig::new(vec![9], schema.clone(), None, 0).is_err());
         // Nested field of list is not allowed to be used for equality delete
-        assert!(EqualityDeleteWriterConfig::new(vec![10], schema.clone(), None).is_err());
-        assert!(EqualityDeleteWriterConfig::new(vec![11], schema.clone(), None).is_err());
+        assert!(EqualityDeleteWriterConfig::new(vec![10], schema.clone(), None, 0).is_err());
+        assert!(EqualityDeleteWriterConfig::new(vec![11], schema.clone(), None, 0).is_err());
 
         Ok(())
     }
@@ -551,7 +561,8 @@ mod test {
                 .unwrap(),
         );
         let equality_ids = vec![0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13];
-        let config = EqualityDeleteWriterConfig::new(equality_ids, schema.clone(), None).unwrap();
+        let config =
+            EqualityDeleteWriterConfig::new(equality_ids, schema.clone(), None, 0).unwrap();
         let delete_arrow_schema = config.projected_arrow_schema_ref().clone();
         let delete_schema = arrow_schema_to_schema(&delete_arrow_schema).unwrap();
 
@@ -657,4 +668,109 @@ mod test {
 
         Ok(())
     }
+
+    #[tokio::test]
+    async fn test_equality_delete_with_nullable_field() -> Result<(), anyhow::Error> {
+        // prepare data
+        // Int, Struct(Int), Struct(Struct(Int))
+        let schema = Schema::builder()
+            .with_schema_id(1)
+            .with_fields(vec![
+                NestedField::optional(0, "col0", Type::Primitive(PrimitiveType::Int)).into(),
+                NestedField::optional(
+                    1,
+                    "col1",
+                    Type::Struct(StructType::new(vec![
+                        NestedField::optional(2, "sub_col", Type::Primitive(PrimitiveType::Int))
+                            .into(),
+                    ])),
+                )
+                .into(),
+                NestedField::optional(
+                    3,
+                    "col2",
+                    Type::Struct(StructType::new(vec![
+                        NestedField::optional(
+                            4,
+                            "sub_struct_col",
+                            Type::Struct(StructType::new(vec![
+                                NestedField::optional(
+                                    5,
+                                    "sub_sub_col",
+                                    Type::Primitive(PrimitiveType::Int),
+                                )
+                                .into(),
+                            ])),
+                        )
+                        .into(),
+                    ])),
+                )
+                .into(),
+            ])
+            .build()
+            .unwrap();
+        let arrow_schema = Arc::new(schema_to_arrow_schema(&schema).unwrap());
+        // null 1            null(struct)
+        // 2    null(struct) null(sub_struct_col)
+        // 3    null(field)  null(sub_sub_col)
+        let col0 = Arc::new(Int32Array::from(vec![None, Some(2), Some(3)])) as ArrayRef;
+        let col1 = {
+            let nulls = NullBuffer::from(vec![true, false, true]);
+            Arc::new(StructArray::new(
+                if let DataType::Struct(fields) = arrow_schema.fields.get(1).unwrap().data_type() {
+                    fields.clone()
+                } else {
+                    unreachable!()
+                },
+                vec![Arc::new(Int32Array::from(vec![Some(1), Some(2), None]))],
+                Some(nulls),
+            ))
+        };
+        let col2 = {
+            let inner_col = {
+                let nulls = NullBuffer::from(vec![true, false, true]);
+                Arc::new(StructArray::new(
+                    Fields::from(vec![
+                        Field::new("sub_sub_col", DataType::Int32, true).with_metadata(
+                            HashMap::from([(
+                                PARQUET_FIELD_ID_META_KEY.to_string(),
+                                "5".to_string(),
+                            )]),
+                        ),
+                    ]),
+                    vec![Arc::new(Int32Array::from(vec![Some(1), Some(2), None]))],
+                    Some(nulls),
+                ))
+            };
+            let nulls = NullBuffer::from(vec![false, true, true]);
+            Arc::new(StructArray::new(
+                if let DataType::Struct(fields) = arrow_schema.fields.get(2).unwrap().data_type() {
+                    fields.clone()
+                } else {
+                    unreachable!()
+                },
+                vec![inner_col],
+                Some(nulls),
+            ))
+        };
+        let columns = vec![col0, col1, col2];
+
+        let to_write = RecordBatch::try_new(arrow_schema.clone(), columns).unwrap();
+        let equality_ids = vec![0_i32, 2, 5];
+        let equality_config =
+            EqualityDeleteWriterConfig::new(equality_ids, Arc::new(schema), None, 0).unwrap();
+        let projector = equality_config.projector.clone();
+
+        // check
+        let to_write_projected = projector.project_batch(to_write)?;
+        let expect_batch =
+            RecordBatch::try_new(equality_config.projected_arrow_schema_ref().clone(), vec![
+                Arc::new(Int32Array::from(vec![None, Some(2), Some(3)])) as ArrayRef,
+                Arc::new(Int32Array::from(vec![Some(1), None, None])) as ArrayRef,
+                Arc::new(Int32Array::from(vec![None, None, None])) as ArrayRef,
+            ])
+            .unwrap();
+        assert_eq!(to_write_projected, expect_batch);
+        Ok(())
+    }
 }
